static const struct {
  int start; int end;
} ranges[] = {
  {0x000030,0x000039},
  {0x000041,0x00005a},
  {0x000061,0x00007a},
  {0x0000c6,0x0000d6},
  {0x0000d8,0x0000f6},
  {0x0000f8,0x0002c1},
  {0x0002c6,0x0002d1},
  {0x0002ec,0x0002ec},
  {0x0002ee,0x0002ee},
  {0x000300,0x000374},
  {0x000376,0x000377},
  {0x00037b,0x00037d},
  {0x000391,0x0003a1},
  {0x0003a3,0x0003f5},
  {0x0003f7,0x000481},
  {0x000483,0x000487},
  {0x00048a,0x000523},
  {0x000531,0x000556},
  {0x000559,0x000559},
  {0x000561,0x000587},
  {0x000591,0x0005bd},
  {0x0005bf,0x0005bf},
  {0x0005c1,0x0005c2},
  {0x0005c4,0x0005c5},
  {0x0005c7,0x0005c7},
  {0x0005d0,0x0005ea},
  {0x0005f0,0x0005f2},
  {0x000610,0x00061a},
  {0x000621,0x00065e},
  {0x000660,0x000669},
  {0x00066e,0x0006d3},
  {0x0006d5,0x0006dc},
  {0x0006df,0x0006e8},
  {0x0006ea,0x0006fc},
  {0x0006ff,0x0006ff},
  {0x000710,0x00074a},
  {0x00074d,0x0007b1},
  {0x0007c0,0x0007f5},
  {0x0007fa,0x0007fa},
  {0x000901,0x000902},
  {0x000904,0x000939},
  {0x00093c,0x00093d},
  {0x000941,0x000948},
  {0x00094d,0x00094d},
  {0x000950,0x000954},
  {0x000960,0x000963},
  {0x000966,0x00096f},
  {0x000971,0x000972},
  {0x00097b,0x00097f},
  {0x000981,0x000981},
  {0x000985,0x00098c},
  {0x00098f,0x000990},
  {0x000993,0x0009a8},
  {0x0009aa,0x0009b0},
  {0x0009b2,0x0009b2},
  {0x0009b6,0x0009b9},
  {0x0009bc,0x0009bd},
  {0x0009c1,0x0009c4},
  {0x0009cd,0x0009ce},
  {0x0009e0,0x0009e3},
  {0x0009e6,0x0009f1},
  {0x0009f4,0x0009f9},
  {0x000a01,0x000a02},
  {0x000a05,0x000a0a},
  {0x000a0f,0x000a10},
  {0x000a13,0x000a28},
  {0x000a2a,0x000a30},
  {0x000a32,0x000a33},
  {0x000a35,0x000a36},
  {0x000a38,0x000a39},
  {0x000a3c,0x000a3c},
  {0x000a41,0x000a42},
  {0x000a47,0x000a48},
  {0x000a4b,0x000a4d},
  {0x000a51,0x000a51},
  {0x000a5c,0x000a5c},
  {0x000a66,0x000a75},
  {0x000a81,0x000a82},
  {0x000a85,0x000a8d},
  {0x000a8f,0x000a91},
  {0x000a93,0x000aa8},
  {0x000aaa,0x000ab0},
  {0x000ab2,0x000ab3},
  {0x000ab5,0x000ab9},
  {0x000abc,0x000abd},
  {0x000ac1,0x000ac5},
  {0x000ac7,0x000ac8},
  {0x000acd,0x000acd},
  {0x000ad0,0x000ad0},
  {0x000ae0,0x000ae3},
  {0x000ae6,0x000aef},
  {0x000b01,0x000b01},
  {0x000b05,0x000b0c},
  {0x000b0f,0x000b10},
  {0x000b13,0x000b28},
  {0x000b2a,0x000b30},
  {0x000b32,0x000b33},
  {0x000b35,0x000b39},
  {0x000b3c,0x000b3d},
  {0x000b3f,0x000b3f},
  {0x000b41,0x000b44},
  {0x000b4d,0x000b4d},
  {0x000b56,0x000b56},
  {0x000b5f,0x000b63},
  {0x000b66,0x000b6f},
  {0x000b71,0x000b71},
  {0x000b82,0x000b83},
  {0x000b85,0x000b8a},
  {0x000b8e,0x000b90},
  {0x000b92,0x000b95},
  {0x000b99,0x000b9a},
  {0x000b9c,0x000b9c},
  {0x000b9e,0x000b9f},
  {0x000ba3,0x000ba4},
  {0x000ba8,0x000baa},
  {0x000bae,0x000bb9},
  {0x000bc0,0x000bc0},
  {0x000bcd,0x000bcd},
  {0x000bd0,0x000bd0},
  {0x000be6,0x000bf2},
  {0x000c05,0x000c0c},
  {0x000c0e,0x000c10},
  {0x000c12,0x000c28},
  {0x000c2a,0x000c33},
  {0x000c35,0x000c39},
  {0x000c3d,0x000c40},
  {0x000c46,0x000c48},
  {0x000c4a,0x000c4d},
  {0x000c55,0x000c56},
  {0x000c58,0x000c59},
  {0x000c60,0x000c63},
  {0x000c66,0x000c6f},
  {0x000c78,0x000c7e},
  {0x000c85,0x000c8c},
  {0x000c8e,0x000c90},
  {0x000c92,0x000ca8},
  {0x000caa,0x000cb3},
  {0x000cb5,0x000cb9},
  {0x000cbc,0x000cbd},
  {0x000cbf,0x000cbf},
  {0x000cc6,0x000cc6},
  {0x000ccc,0x000ccd},
  {0x000cde,0x000cde},
  {0x000ce0,0x000ce3},
  {0x000ce6,0x000cef},
  {0x000d05,0x000d0c},
  {0x000d0e,0x000d10},
  {0x000d12,0x000d28},
  {0x000d2a,0x000d39},
  {0x000d3d,0x000d3d},
  {0x000d41,0x000d44},
  {0x000d4d,0x000d4d},
  {0x000d60,0x000d63},
  {0x000d66,0x000d75},
  {0x000d7a,0x000d7f},
  {0x000d85,0x000d96},
  {0x000d9a,0x000db1},
  {0x000db3,0x000dbb},
  {0x000dbd,0x000dbd},
  {0x000dc0,0x000dc6},
  {0x000dca,0x000dca},
  {0x000dd2,0x000dd4},
  {0x000dd6,0x000dd6},
  {0x000e01,0x000e3a},
  {0x000e40,0x000e4e},
  {0x000e50,0x000e59},
  {0x000e81,0x000e82},
  {0x000e84,0x000e84},
  {0x000e87,0x000e88},
  {0x000e8a,0x000e8a},
  {0x000e8d,0x000e8d},
  {0x000e94,0x000e97},
  {0x000e99,0x000e9f},
  {0x000ea1,0x000ea3},
  {0x000ea5,0x000ea5},
  {0x000ea7,0x000ea7},
  {0x000eaa,0x000eab},
  {0x000ead,0x000eb9},
  {0x000ebb,0x000ebd},
  {0x000ec0,0x000ec4},
  {0x000ec6,0x000ec6},
  {0x000ec8,0x000ecd},
  {0x000ed0,0x000ed9},
  {0x000f00,0x000f00},
  {0x000f18,0x000f19},
  {0x000f20,0x000f33},
  {0x000f35,0x000f35},
  {0x000f37,0x000f37},
  {0x000f39,0x000f39},
  {0x000f40,0x000f47},
  {0x000f49,0x000f6c},
  {0x000f71,0x000f7e},
  {0x000f80,0x000f84},
  {0x000f86,0x000f8b},
  {0x000f90,0x000f97},
  {0x000f99,0x000fbc},
  {0x000fc6,0x000fc6},
  {0x001000,0x00102a},
  {0x00102d,0x001030},
  {0x001032,0x001037},
  {0x001039,0x00103a},
  {0x00103d,0x001049},
  {0x001050,0x001055},
  {0x001058,0x001061},
  {0x001065,0x001066},
  {0x00106e,0x001082},
  {0x001085,0x001086},
  {0x00108d,0x00108e},
  {0x001090,0x001099},
  {0x0010a0,0x0010c5},
  {0x0010d0,0x0010fa},
  {0x001100,0x001159},
  {0x00115f,0x0011a2},
  {0x0011a8,0x0011f9},
  {0x001200,0x001248},
  {0x00124a,0x00124d},
  {0x001250,0x001256},
  {0x001258,0x001258},
  {0x00125a,0x00125d},
  {0x001260,0x001288},
  {0x00128a,0x00128d},
  {0x001290,0x0012b0},
  {0x0012b2,0x0012b5},
  {0x0012b8,0x0012be},
  {0x0012c0,0x0012c0},
  {0x0012c2,0x0012c5},
  {0x0012c8,0x0012d6},
  {0x0012d8,0x001310},
  {0x001312,0x001315},
  {0x001318,0x00135a},
  {0x00135f,0x00135f},
  {0x001369,0x00137c},
  {0x001380,0x00138f},
  {0x0013a0,0x0013f4},
  {0x001401,0x00166c},
  {0x00166f,0x001676},
  {0x001681,0x00169a},
  {0x0016a0,0x0016ea},
  {0x0016ee,0x0016f0},
  {0x001700,0x00170c},
  {0x00170e,0x001714},
  {0x001720,0x001734},
  {0x001740,0x001753},
  {0x001760,0x00176c},
  {0x00176e,0x001770},
  {0x001772,0x001773},
  {0x001780,0x0017b3},
  {0x0017b7,0x0017bd},
  {0x0017c6,0x0017c6},
  {0x0017c9,0x0017d3},
  {0x0017d7,0x0017d7},
  {0x0017dc,0x0017dd},
  {0x0017e0,0x0017e9},
  {0x0017f0,0x0017f9},
  {0x00180b,0x00180d},
  {0x001810,0x001819},
  {0x001820,0x001877},
  {0x001880,0x0018aa},
  {0x001900,0x00191c},
  {0x001920,0x001922},
  {0x001927,0x001928},
  {0x001932,0x001932},
  {0x001939,0x00193b},
  {0x001946,0x00196d},
  {0x001970,0x001974},
  {0x001980,0x0019a9},
  {0x0019c1,0x0019c7},
  {0x0019d0,0x0019d9},
  {0x001a00,0x001a18},
  {0x001b00,0x001b03},
  {0x001b05,0x001b34},
  {0x001b36,0x001b3a},
  {0x001b3c,0x001b3c},
  {0x001b42,0x001b42},
  {0x001b45,0x001b4b},
  {0x001b50,0x001b59},
  {0x001b6b,0x001b73},
  {0x001b80,0x001b81},
  {0x001b83,0x001ba0},
  {0x001ba2,0x001ba5},
  {0x001ba8,0x001ba9},
  {0x001bae,0x001bb9},
  {0x001c00,0x001c23},
  {0x001c2c,0x001c33},
  {0x001c36,0x001c37},
  {0x001c40,0x001c49},
  {0x001c4d,0x001c7d},
  {0x001d00,0x001de6},
  {0x001dfe,0x001f15},
  {0x0020d0,0x0020dc},
  {0x0020e1,0x0020e1},
  {0x0020e5,0x0020f0},
  {0x002132,0x002139},
  {0x00214e,0x00214e},
  {0x002180,0x002188},
  {0x0024eb,0x0024ff},
  {0x002776,0x002793},
  {0x002c00,0x002c2e},
  {0x002c30,0x002c5e},
  {0x002c60,0x002c6f},
  {0x002c71,0x002c7d},
  {0x002c80,0x002ce4},
  {0x002cfd,0x002cfd},
  {0x002d00,0x002d25},
  {0x002d30,0x002d65},
  {0x002d80,0x002d96},
  {0x002da0,0x002da6},
  {0x002da8,0x002dae},
  {0x002db0,0x002db6},
  {0x002db8,0x002dbe},
  {0x002dc0,0x002dc6},
  {0x002dc8,0x002dce},
  {0x002dd0,0x002dd6},
  {0x002dd8,0x002dde},
  {0x002de0,0x002dff},
  {0x002e2f,0x002e2f},
  {0x003005,0x003007},
  {0x003021,0x00302f},
  {0x003031,0x003035},
  {0x00303b,0x00303c},
  {0x003041,0x003096},
  {0x003099,0x00309a},
  {0x00309d,0x00309f},
  {0x0030a1,0x0030fa},
  {0x0030fc,0x0030ff},
  {0x003105,0x00312d},
  {0x0031a0,0x0031b7},
  {0x0031f0,0x0031ff},
  {0x003400,0x004db5},
  {0x004e00,0x009fc3},
  {0x00a000,0x00a48c},
  {0x00a500,0x00a60c},
  {0x00a610,0x00a62b},
  {0x00a640,0x00a65f},
  {0x00a662,0x00a66f},
  {0x00a67c,0x00a67d},
  {0x00a67f,0x00a697},
  {0x00a717,0x00a71f},
  {0x00a722,0x00a788},
  {0x00a78b,0x00a78c},
  {0x00a7fb,0x00a822},
  {0x00a825,0x00a826},
  {0x00a840,0x00a873},
  {0x00a882,0x00a8b3},
  {0x00a8c4,0x00a8c4},
  {0x00a8d0,0x00a8d9},
  {0x00a900,0x00a92d},
  {0x00a930,0x00a951},
  {0x00aa00,0x00aa2e},
  {0x00aa31,0x00aa32},
  {0x00aa35,0x00aa36},
  {0x00aa40,0x00aa4c},
  {0x00aa50,0x00aa59},
  {0x00ac00,0x00d7a3},
  {0x00fa0e,0x00fa2d},
  {0x00fb1e,0x00fb28},
  {0x00fe00,0x00fe0f},
  {0x00fe20,0x00fe26},
  {0x00fe73,0x00fe74},
  {0x010000,0x01000b},
  {0x01000d,0x010026},
  {0x010028,0x01003a},
  {0x01003c,0x01003d},
  {0x01003f,0x01004d},
  {0x010050,0x01005d},
  {0x010080,0x0100fa},
  {0x010107,0x010133},
  {0x010140,0x010178},
  {0x01018a,0x01018a},
  {0x0101fd,0x0101fd},
  {0x010280,0x01029c},
  {0x0102a0,0x0102d0},
  {0x010300,0x01031e},
  {0x010320,0x010323},
  {0x010330,0x01034a},
  {0x010380,0x01039d},
  {0x0103a0,0x0103c3},
  {0x0103c8,0x0103cf},
  {0x0103d1,0x0103d5},
  {0x010400,0x01049d},
  {0x0104a0,0x0104a9},
  {0x010800,0x010805},
  {0x010808,0x010808},
  {0x01080a,0x010835},
  {0x010837,0x010838},
  {0x01083c,0x01083c},
  {0x01083f,0x01083f},
  {0x010900,0x010919},
  {0x010920,0x010939},
  {0x010a00,0x010a03},
  {0x010a05,0x010a06},
  {0x010a0c,0x010a13},
  {0x010a15,0x010a17},
  {0x010a19,0x010a33},
  {0x010a38,0x010a3a},
  {0x010a3f,0x010a47},
  {0x012000,0x01236e},
  {0x012400,0x012462},
  {0x01d167,0x01d169},
  {0x01d17b,0x01d182},
  {0x01d185,0x01d18b},
  {0x01d1aa,0x01d1ad},
  {0x01d242,0x01d244},
  {0x01d360,0x01d371},
  {0x020000,0x02a6d6},
  {0x0e0100,0x0e01ef},
};
